@@ -1,4 +1,5 @@
 import builtins
+from collections.abc import Iterable
 import operator
 from functools import partial, wraps
 from itertools import product, repeat
@@ -20,7 +21,7 @@ from .wrap import zeros, ones
 from .numpy_compat import ma_divide, divide as np_divide
 from ..base import tokenize
 from ..highlevelgraph import HighLevelGraph
-from ..utils import ignoring, funcname, Dispatch, deepmap, getargspec
+from ..utils import ignoring, funcname, Dispatch, deepmap, getargspec, derived_from
 from .. import config
 
 # Generic functions to support chunks of different types
@@ -326,17 +327,15 @@ def partial_reduce(
 
 @wraps(chunk.sum)
 def sum(a, axis=None, dtype=None, keepdims=False, split_every=None, out=None):
-    if dtype is not None:
-        dt = dtype
-    else:
-        dt = getattr(np.empty((1,), dtype=a.dtype).sum(), "dtype", object)
+    if dtype is None:
+        dtype = getattr(np.zeros(1, dtype=a.dtype).sum(), "dtype", object)
     result = reduction(
         a,
         chunk.sum,
         chunk.sum,
         axis=axis,
         keepdims=keepdims,
-        dtype=dt,
+        dtype=dtype,
         split_every=split_every,
         out=out,
     )
@@ -814,7 +813,8 @@ with ignoring(AttributeError):
 @wraps(chunk.std)
 def std(a, axis=None, dtype=None, keepdims=False, ddof=0, split_every=None, out=None):
     result = sqrt(
-        a.var(
+        var(
+            a,
             axis=axis,
             dtype=dtype,
             keepdims=keepdims,
@@ -1253,3 +1253,36 @@ def argtopk(a, k, axis=-1, split_every=None):
 @wraps(np.trace)
 def trace(a, offset=0, axis1=0, axis2=1, dtype=None):
     return diagonal(a, offset=offset, axis1=axis1, axis2=axis2).sum(-1, dtype=dtype)
+
+
+@derived_from(np)
+def median(a, axis=None, keepdims=False, out=None):
+    """
+    This works by automatically chunking the reduced axes to a single chunk
+    and then calling ``numpy.median`` function across the remaining dimensions
+    """
+    if axis is None:
+        raise NotImplementedError(
+            "The da.median function only works along an axis.  "
+            "The full algorithm is difficult to do in parallel"
+        )
+
+    if not isinstance(axis, Iterable):
+        axis = (axis,)
+
+    axis = [ax + a.ndim if ax < 0 else ax for ax in axis]
+
+    a = a.rechunk({ax: -1 if ax in axis else "auto" for ax in range(a.ndim)})
+
+    result = a.map_blocks(
+        np.median,
+        axis=axis,
+        keepdims=keepdims,
+        drop_axis=axis if not keepdims else None,
+        chunks=[1 if ax in axis else c for ax, c in enumerate(a.chunks)]
+        if keepdims
+        else None,
+    )
+
+    result = handle_out(out, result)
+    return result
