@@ -49,6 +49,9 @@ def test_numel(dtype, keepdims):
 
 def reduction_1d_test(da_func, darr, np_func, narr, use_dtype=True, split_every=True):
     assert_eq(da_func(darr), np_func(narr))
+    assert_eq(
+        da_func(narr), np_func(narr)
+    )  # Ensure Dask reductions work with NumPy arrays
     assert_eq(da_func(darr, keepdims=True), np_func(narr, keepdims=True))
     assert_eq(da_func(darr, axis=()), np_func(narr, axis=()))
     assert same_keys(da_func(darr), da_func(darr))
@@ -663,3 +666,15 @@ def test_trace():
     _assert(a, b, 0, 1, 2, float)
     _assert(a, b, offset=1, axis1=0, axis2=2, dtype=int)
     _assert(a, b, offset=1, axis1=0, axis2=2, dtype=float)
+
+
+@pytest.mark.parametrize("axis", [0, [0, 1], 1, -1])
+@pytest.mark.parametrize("keepdims", [True, False])
+def test_median(axis, keepdims):
+    x = np.arange(100).reshape((2, 5, 10))
+    d = da.from_array(x, chunks=2)
+
+    assert_eq(
+        da.median(d, axis=axis, keepdims=keepdims),
+        np.median(x, axis=axis, keepdims=keepdims),
+    )
