@@ -31,7 +31,7 @@ def _get_md_row_groups(pieces):
             row_group = piece.get_metadata().row_group(rg)
             for c in range(row_group.num_columns):
                 if not row_group.column(c).statistics:
-                    return []
+                    return (None, None)
             row_groups.append(row_group)
         row_groups_per_piece.append(num_row_groups)
     if len(row_groups) == len(pieces):
@@ -77,8 +77,7 @@ def _determine_dataset_parts(fs, paths, gather_statistics, filters, dataset_kwar
             )
         else:
             base, fns = _analyze_paths(paths, fs)
-            relpaths = [path.replace(base, "").lstrip("/") for path in paths]
-            if "_metadata" in relpaths:
+            if "_metadata" in fns:
                 # We have a _metadata file, lets use it
                 dataset = pq.ParquetDataset(
                     base + fs.sep + "_metadata",
@@ -91,36 +90,32 @@ def _determine_dataset_parts(fs, paths, gather_statistics, filters, dataset_kwar
                 # Will need to pass a list of paths to read_partition
                 dataset = pq.ParquetDataset(paths[0], filesystem=fs, **dataset_kwargs)
                 parts = [base + fs.sep + fn for fn in fns]
-    else:
-        if fs.isdir(paths[0]):
-            # This is a directory, check for _metadata, then _common_metadata
-            allpaths = fs.glob(paths[0] + fs.sep + "*")
-            base, fns = _analyze_paths(allpaths, fs)
-            relpaths = [path.replace(base, "").lstrip("/") for path in allpaths]
-            if "_metadata" in relpaths and "validate_schema" not in dataset_kwargs:
-                dataset_kwargs["validate_schema"] = False
-            if "_metadata" in relpaths or gather_statistics is not False:
-                # Let arrow do its thing (use _metadata or scan files)
+    elif fs.isdir(paths[0]):
+        # This is a directory, check for _metadata, then _common_metadata
+        allpaths = fs.glob(paths[0] + fs.sep + "*")
+        base, fns = _analyze_paths(allpaths, fs)
+        if "_metadata" in fns and "validate_schema" not in dataset_kwargs:
+            dataset_kwargs["validate_schema"] = False
+        if "_metadata" in fns or gather_statistics is not False:
+            # Let arrow do its thing (use _metadata or scan files)
+            dataset = pq.ParquetDataset(
+                paths, filesystem=fs, filters=filters, **dataset_kwargs
+            )
+        else:
+            # Use _common_metadata file if it is available.
+            # Otherwise, just use 0th file
+            if "_common_metadata" in fns:
                 dataset = pq.ParquetDataset(
-                    paths, filesystem=fs, filters=filters, **dataset_kwargs
+                    base + fs.sep + "_common_metadata", filesystem=fs, **dataset_kwargs
                 )
             else:
-                # Use _common_metadata file if it is available.
-                # Otherwise, just use 0th file
-                if "_common_metadata" in relpaths:
-                    dataset = pq.ParquetDataset(
-                        base + fs.sep + "_common_metadata",
-                        filesystem=fs,
-                        **dataset_kwargs,
-                    )
-                else:
-                    dataset = pq.ParquetDataset(
-                        allpaths[0], filesystem=fs, **dataset_kwargs
-                    )
-                parts = [base + fs.sep + fn for fn in fns]
-        else:
-            # There is only one file to read
-            dataset = pq.ParquetDataset(paths, filesystem=fs, **dataset_kwargs)
+                dataset = pq.ParquetDataset(
+                    allpaths[0], filesystem=fs, **dataset_kwargs
+                )
+            parts = [base + fs.sep + fn for fn in fns]
+    else:
+        # There is only one file to read
+        dataset = pq.ParquetDataset(paths, filesystem=fs, **dataset_kwargs)
     return parts, dataset
 
 
@@ -268,6 +263,7 @@ class ArrowEngine(Engine):
                                 }
                             )
                         s["columns"].append(d)
+                s["total_byte_size"] = row_group.total_byte_size
                 stats.append(s)
         else:
             stats = None
@@ -294,10 +290,15 @@ class ArrowEngine(Engine):
             if split_row_groups and row_groups_per_piece:
                 # TODO: This block can be removed after ARROW-2801
                 parts = []
+                rg_tot = 0
                 for i, piece in enumerate(pieces):
                     num_row_groups = row_groups_per_piece[i]
                     for rg in range(num_row_groups):
                         parts.append((piece.path, rg, piece.partition_keys))
+                        # Setting file_path here, because it may be
+                        # missing from the row-group/column-chunk stats
+                        stats[rg_tot]["file_path_0"] = piece.path
+                        rg_tot += 1
             else:
                 parts = [
                     (piece.path, piece.row_group, piece.partition_keys)
@@ -326,12 +327,14 @@ class ArrowEngine(Engine):
             )
         else:
             # `piece` contains (path, row_group, partition_keys)
+            (path, row_group, partition_keys) = piece
             piece = pq.ParquetDatasetPiece(
-                piece[0],
-                row_group=piece[1],
-                partition_keys=piece[2],
+                path,
+                row_group=row_group,
+                partition_keys=partition_keys,
                 open_file_func=partial(fs.open, mode="rb"),
             )
+
         df = piece.read(
             columns=columns,
             partitions=partitions,
